@@ -57,6 +57,8 @@ sysbench.cmdline.options = {
       {"Use purge transaction (yes, no)", "no"},
    report_csv =
       {"Report output in csv (yes, no)", "no"},
+   pgsql_schema =
+      {"Schema name for Pg(default:public)", "public"},
    mysql_storage_engine =
       {"Storage engine, if MySQL is used", "innodb"},
    mysql_table_options =
@@ -67,17 +69,31 @@ function sleep(n)
   os.execute("sleep " .. tonumber(n))
 end
 
--- Create the tables and Prepare the dataset. This command supports parallel execution, i.e. will
--- benefit from executing with --threads > 1 as long as --scale > 1
-function cmd_prepare()
+function db_connection_init()
    local drv = sysbench.sql.driver()
    local con = drv:connect()
-   local show_query="SHOW TABLES"
+
+   set_isolation_level(drv,con)
 
    if drv:name() == "mysql" then 
       con:query("SET FOREIGN_KEY_CHECKS=0")
+      con:query("SET autocommit=0")
    end
 
+   if drv:name() == "pgsql" then
+     con:query("SET search_path TO " .. sysbench.opt.pgsql_schema)
+     print ("DB SCHEMA ".. sysbench.opt.pgsql_schema)
+   end
+
+   return drv,con
+end
+
+-- Create the tables and Prepare the dataset. This command supports parallel execution, i.e. will
+-- benefit from executing with --threads > 1 as long as --scale > 1
+function cmd_prepare()
+
+   local drv,con = db_connection_init()
+
    -- create tables in parallel table per thread
    for i = sysbench.tid % sysbench.opt.threads + 1, sysbench.opt.tables,
    sysbench.opt.threads do
@@ -99,8 +115,8 @@ end
 -- Check consistency 
 -- benefit from executing with --threads > 1 as long as --scale > 1
 function cmd_check()
-   local drv = sysbench.sql.driver()
-   local con = drv:connect()
+
+   local drv,con = db_connection_init()
 
    for i = sysbench.tid % sysbench.opt.threads + 1, sysbench.opt.scale,
    sysbench.opt.threads do
@@ -324,7 +340,7 @@ function create_tables(drv, con, table_num)
  
       query = string.format([[(%d,%d,'%s',%f,'%s')]],
 	j, i_im_id, i_name:sub(1,24), i_price, i_data:sub(1,50))
-      con:bulk_insert_next(query)
+        con:bulk_insert_next(query)
 		 
    end
    con:bulk_insert_done()
@@ -349,7 +365,6 @@ function create_tables(drv, con, table_num)
         con:query("ALTER TABLE stock"..i.." ADD CONSTRAINT fkey_stock_1_"..table_num.." FOREIGN KEY(s_w_id) REFERENCES warehouse"..i.."(w_id)")
         con:query("ALTER TABLE stock"..i.." ADD CONSTRAINT fkey_stock_2_"..table_num.." FOREIGN KEY(s_i_id) REFERENCES item"..i.."(i_id)")
     end
-
 end
 
 
@@ -392,8 +407,8 @@ function load_tables(drv, con, warehouse_num)
    local extra_table_options = ""
    local query
 
-   set_isolation_level(drv,con)
-   
+   con:query("SET autocommit=1")
+
    -- print(string.format("Creating warehouse: %d\n", warehouse_num))
 
    for table_num = 1, sysbench.opt.tables do 
@@ -407,8 +422,8 @@ function load_tables(drv, con, warehouse_num)
 	warehouse_num, sysbench.rand.string("name-@@@@@"), sysbench.rand.string("street1-@@@@@@@@@@"),
         sysbench.rand.string("street2-@@@@@@@@@@"), sysbench.rand.string("city-@@@@@@@@@@"),
         sysbench.rand.string("@@"),sysbench.rand.string("zip-#####"),sysbench.rand.uniform_double()*0.2 )
-      con:bulk_insert_next(query)
-		 
+
+    con:bulk_insert_next(query)
     con:bulk_insert_done()
 
     con:bulk_insert_init("INSERT INTO district" .. table_num .. 
@@ -423,7 +438,7 @@ function load_tables(drv, con, warehouse_num)
       con:bulk_insert_next(query)
 
    end
- con:bulk_insert_done()
+   con:bulk_insert_done()
 
 -- CUSTOMER TABLE
 
@@ -570,24 +585,14 @@ function load_tables(drv, con, warehouse_num)
 
 end
 
-function thread_init()
-   drv = sysbench.sql.driver()
-   con = drv:connect()
-   con:query("SET AUTOCOMMIT=0")
-
-end
 
 function thread_done()
    con:disconnect()
 end
 
 function cleanup()
-   local drv = sysbench.sql.driver()
-   local con = drv:connect()
 
-   if drv:name() == "mysql" then 
-      con:query("SET FOREIGN_KEY_CHECKS=0")
-   end
+   local drv,con = db_connection_init()
 
    for i = 1, sysbench.opt.tables do
       print(string.format("Dropping tables '%d'...", i))
